# ... uncategorized `prybahr` stuff

## opinionated

* documentation
* git vs other VCS
* smaller git repos + use of submodules
  * eschew the mono-repo
* github
* PyCharm (for Python3)
* Python3 as end-goal, or Python3 as means-to-an-end
* pipenv, pyenv
  * original goal was to "bootstrap" development, but way too much work
* Development aid
* Docker
* Kubernetes
  * when Kubernetes is too slow or error-prone ... Docker
* PostgreSQL over ...
  * MongoDB et al
  * MySQL / MariaDB
  * ...
* useful tools:
  * Balsamiq?
  * Monodraw (from Helftone)
* prybahr utilities:
  * development
    * Python3-file (and other file) tagging / formatting
    * ...
  * ...
* ...

## ==